#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 casa-client
version:              0.0.3
visibility:           public
id:                   casa-client-0.0.3-74a2ZxY6VDPEuHPf4UzOsr
key:                  casa-client-0.0.3-74a2ZxY6VDPEuHPf4UzOsr
license:              BSD-3-Clause
copyright:
    2018-2019 FP Complete,
    2024-2025 Haskell Foundation

maintainer:
    Chris Done <chrisdone@fpcomplete.com>,
    Mike Pilgrem <public@pilgrem.com>

author:               Chris Done
homepage:             https://github.com/commercialhaskell/casa#readme
synopsis:             Client for Casa
description:
    Client for Casa (Content-Addressable Storage Archive). See
    <https://casa.stackage.org/>

category:             Development
abi:                  b21eb2c366725796c489494c9778ccdb
exposed:              True
exposed-modules:      Casa.Client
import-dirs:          /usr/lib/ghc-9.6.6/site-local/casa-client-0.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/casa-client-0.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/casa-client-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-client
hs-libraries:         HScasa-client-0.0.3-74a2ZxY6VDPEuHPf4UzOsr
depends:
    aeson-2.2.1.0-IFj7FSeQ5R79PZnh3ksXrW
    attoparsec-0.14.4-3CmiIm11iun2BHKDR4ovn7 base-4.18.2.1
    base16-bytestring-1.0.2.0-31yUxkNIVeJ6WQ1ftMFCcb
    bytestring-0.11.5.3 casa-types-0.0.3-U5GR91CjqNJPdVQJNscsx
    conduit-1.3.6.1-1yIrQJAoba7Gda6MAs4N1q
    conduit-extra-1.3.8-93QFAm2w4c39bgstz0dQjA
    crypton-1.0.4-BW3r2zHLDkn5MXOxLzl4Qy exceptions-0.10.7
    http-conduit-2.3.9.1-1jgAUVyqkxJ6z3Pvba5xG2
    http-types-0.12.4-4tdX51H3YCXI63KUlr8q5w
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-uri-2.6.4.2-1K7fB5RWUkvJzcj2EjtnE4
    resourcet-1.2.6-GrVaNPG3RF7IMcvlKlmJk8 template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.6-259dLbfPJk9HrfYIeZHdvQ
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq

haddock-interfaces:   /usr/share/doc/haskell-casa-client/html/casa-client.haddock
haddock-html:         /usr/share/doc/haskell-casa-client/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

